@@ -3,7 +3,7 @@
 
 #include <QPushButton>
 
-
+class QTimer;
 
 class EmittingButton:public QPushButton
 {
@@ -12,17 +12,23 @@ class EmittingButton:public QPushButton
 
 private:
     double freq;
+    int index;
+    QTimer *timer;
 
 
 
 public:
-    EmittingButton(QWidget *parent, double);
+    EmittingButton(QWidget *parent, double, int);
 
 signals:
     void buttonClicked(int);
+    void buttonIsHold(int);
 
 public slots:
     void buttonIsClicked();
+    void buttonReleased();
+    void timeout();
+
 
 };
 
